package Bugzilla::Extension::ActivityReport;

use strict;
use warnings;
use 5.10.1;

use base qw(Bugzilla::Extension);
use Bugzilla::Util;

use Bugzilla::Extension::ActivityReport::Reports qw(user_activity_report
  user_admin_activity_report
  group_admins_report
  group_membership_report
  email_queue_report);

# Hooks in to other modules.
BEGIN {
  *Bugzilla::Object::admin_link = \&_admin_link;
}

sub page_before_template {
  my ($self, $args) = @_;
  my $page = $args->{'page_id'};
  my $vars = $args->{'vars'};

  if ($page eq 'user_activity.html') {
    user_activity_report($vars);
  }
  elsif ($page eq 'user_admin_activity.html') {
    user_admin_activity_report($vars);
  }
  elsif ($page eq 'group_admins.html') {
    group_admins_report($vars);
  }
  elsif ($page eq 'group_membership.html' or $page eq 'group_membership.txt') {
    group_membership_report($page, $vars);
  }
  elsif ($page eq 'email_queue.html') {
    email_queue_report($vars);
  }

  return;
}


#####################
# Webservice bindings
#####################

sub webservice {
  my ($self, $args) = @_;

  my $dispatch = $args->{dispatch};

  $dispatch->{'ActivityReport'}
    = "Bugzilla::Extension::ActivityReport::WebService";

  return;
}

sub _admin_link {
  my $self = shift;

  my $link = '';

  my $full_class = ref $self;
  my $class      = $full_class;
  $class = $1 if ($class =~ m/::([^:]*)$/);

  if ($self->isa('Bugzilla::User')) {
    my $name = html_quote($self->identity);
    my $id   = $self->{$self->ID_FIELD};
    $link = qq{$class <a href="editusers.cgi?action=edit&userid=$id">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Group')) {
    my $name = html_quote($self->name);
    my $id   = $self->{$self->ID_FIELD};
    $link
      = qq{$class <a href="editgroups.cgi?action=changeform&group=$id">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Field')) {
    my $name = html_quote($self->name);
    $link = qq{$class <a href="editfields.cgi?action=edit&name=$name">$name</a>};
  }
  elsif ($self->isa('Bugzilla::FlagType')) {
    my $name = html_quote($self->name);
    my $id   = $self->{$self->ID_FIELD};
    $link = qq{$class <a href="editflagtypes.cgi?action=edit&id=$id">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Product')) {
    my $name = html_quote($self->name);
    $link
      = qq{$class <a href="editproducts.cgi?action=edit&product=$name">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Component')) {
    my $name  = html_quote($self->name);
    my $pname = html_quote($self->product->name);
    $link
      = qq{$class <a href="editcomponents.cgi?action=edit&product=$pname&component=$name">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Milestone')) {
    my $name  = html_quote($self->name);
    my $pname = html_quote($self->product->name);
    $link
      = qq{$class <a href="editmilestones.cgi?action=edit&product=$pname&milestone=$name">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Extension::RuleEngine::Rule')) {
    my $name = html_quote($self->name);
    $link
      = qq{$class <a href="page.cgi?id=ruleengine/details/index.html&rule_name=$name">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Extension::RuleEngine::RuleGroup')) {
    my $name = html_quote($self->name);
    my $id   = $self->{$self->ID_FIELD};
    $link
      = qq{$class <a href="page.cgi?id=ruleengine/group/edit.html&rule_group_id=$id">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Extension::SubComponents::RHSubComponent')) {
    my $name = html_quote($self->name);
    my $id   = $self->{$self->ID_FIELD};
    $link
      = qq{$class <a href="ppage.cgi?id=subcomponents/edit.html&product=Bugzilla&component=Extensions&sub_component_id=$id">$class $name</a>};
  }
  elsif ($self->isa('Bugzilla::Version')) {
    my $name  = html_quote($self->name);
    my $pname = html_quote($self->product->name);
    $link
      = qq{$class <a href="editversions.cgi?action=edit&product=$pname&version=$name">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Release')) {
    my $name  = html_quote($self->name);
    my $pname = html_quote($self->product->name);
    $link
      = qq{$class <a href="editreleases.cgi?action=edit&product=$pname&release=$name">$name</a>};
  }
  elsif ($self->isa('Bugzilla::Extension::AgileTools::Team')) {
    my $name = html_quote($self->name);
    my $id   = $self->{$self->ID_FIELD};
    $link
      = qq{$class <a href="page.cgi?id=agiletools/team/show.html&team_id=$id">$name</a>};
  }
  elsif ($self->isa('')) {
    my $name = html_quote($self->name);
    my $id   = $self->{$self->ID_FIELD};
    $link = qq{$class <a href="=$id">$name</a>};
  }
  else {
    $link = "$full_class - " . $self->{$self->ID_FIELD};
  }

  return ($link);
}

__PACKAGE__->NAME;
