# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

package Bugzilla::Extension::ExternalBugs::Config;

use strict;
use warnings;
use 5.10.1;

use Bugzilla::Config::Common;

sub get_param_list {
  my ($class) = @_;

  my @param_list = (
    ## RED HAT EXTENSION START 1175565 1262660
    {
      name => 'enable_external_trackers',
      type => 's',
      choices => [0, 1, 2, 3],   # 0 = no ETs, 1 = all ETs, 2 = No Jira, only QA/Dev SFDC, 3 = #2 + stage Jira
      default => 0,
    },
    ## RED HAT EXTENSION END 1175565 1262660
    {name => 'sfdc_live_server',  type => 't', default => '',},
    {name => 'sfdc_dev_server',   type => 't', default => '',},
    {name => 'sfdc_qa_server',    type => 't', default => '',},
    {name => 'sfdc_stage_server', type => 't', default => '',},
    {
      name    => 'jira_flag_id',
      type    => 't',
      default => '',
      checker => \&check_numeric,
    },
    {
      name    => 'jira_url_id',
      type    => 't',
      default => '',
      checker => \&check_numeric,
    },
    {name => 'jira_post_comments',  type => 'b', default => '0',},
    {name => 'jira_post_status',    type => 'b', default => '1',},
    {name => 'sfdc_hostname',       type => 't', default => ''},
    {name => 'sfdc_sandbox_server', type => 't', default => '',},
## REDHAT EXTENSION START 1510439
    {name => 'ascension_url', type => 't', default => '',},
## REDHAT EXTENSION END 1510439
## REDHAT EXTENSION START 1666269
    {name => 'internal_link_name', type => 't', default => 'Red Hat Bugzilla',},
## REDHAT EXTENSION END 1666269
## REDHAT EXTENSION START 1748737
    {name => 'external_tracker_proxy', type => 't', default => '',},
## REDHAT EXTENSION END 1748737
  );
  return @param_list;
}

1;

__END__

=head1 Description

Bugzilla::Extension::ExternalBugs::Params - A module for specifying parameters to
be added to the data/params.json file.

=head1 Parameters

=over 4

=item ascension_url

The URL to use when mapping SFDC ID's to Adcension.

=item enable_external_trackers

Allow BZ to update JIRA and SFDC external trackers.

0 = no ETs, 1 = all ETs, 2 = No Jira, only QA/Dev SFDC.

=item external_tracker_proxy

The URL of a proxy to use when pulling data.

=item internal_link_name

The Name of the Tracker that is the hosting Bugzilla system. This provides a way
to kink bugs in the hosting system without using the Dependency system.

=item jira_flag_id

The custom field id in JIRA used to track whether the JIRA issue needs to update
Bugzilla.

=item jira_url_id

The custom field id in JIRA used to track what Bugzilla bugs are associated with a
specific JIRA issue.

=item jira_post_comments

If true, any comment made in Bugzilla will be copied to a linked JBoss JIRA issue.

=item jira_post_status

If true, any bug status changes made in Bugzilla will be made as a comment to a
linked JBoss JIRA issue.

=item sfdc_live_server

The hostname (FQDN) for the live (production) SFDC server.

=item sfdc_dev_server

The hostname (FQDN) for the DEV SFDC server.

=item sfdc_qa_server

The hostname (FQDN) for the QA SFDC server.

=item sfdc_stage_server

The hostname (FQDN) for the Stage SFDC server.

=item sfdc_hostname

Hostname for the SFDC server.

=item sfdc_sandbox_server

The hostname (FQDN) for the Stage Sandbox server.

=back

