# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

package Bugzilla::Extension::ExternalBugs::Type::Bugzilla;

use strict;
use warnings;
use 5.10.1;

use base qw(Bugzilla::Extension::ExternalBugs::Type);

use Bugzilla::Util qw(correct_urlbase html_quote);
use Bugzilla::Error;

use HTTP::Cookies;
use XMLRPC::Lite;

use constant TYPE => 'Bugzilla';

my $logger = Bugzilla->logger;

sub get_data {
  my ($self, $ext_bug) = @_;
  my $bug_data;

  eval {
    my $url  = $ext_bug->type->url;
    my $last = chop($url);
    $url .= $last if ($last ne '/');
    $url .= "/xmlrpc.cgi";

    my $rpc;

    if ( Bugzilla->params->{external_tracker_proxy}
      && Bugzilla->params->{external_tracker_proxy} ne '')
    {
      $rpc = new XMLRPC::Lite();
      $rpc->proxy($url,
        proxy => [["http", "https"] => Bugzilla->params->{external_tracker_proxy}]);
    }
    else {
      $rpc = new XMLRPC::Lite(proxy => $url);
    }

    $logger->debug("Bugzilla XMLRPC Calling: $url Bug.get");

    my $call = $rpc->call(
      'Bug.get',
      {ids => [$ext_bug->ext_bz_bug_id]},
      include_fields => ['id', 'status', 'summary', 'priority'],
    );
    my $result = $call->result;

    die $call->faultstring if $call->fault;

    if ($result->{'bugs'}[0]{'status'} && $result->{'bugs'}[0]{'summary'}) {
      $bug_data                  = {};
      $bug_data->{'status'}      = $result->{'bugs'}[0]{'status'};
      $bug_data->{'description'} = $result->{'bugs'}[0]{'summary'};
      $bug_data->{'priority'}    = $result->{'bugs'}[0]{'priority'};
    }
  };

  if ($@) {
    ThrowCodeError('eval_error',
      {command => $ext_bug->type->url . "/xmlrpc.cgi Bug.get", msg => html_quote($@)}
    );
  }

  return $bug_data;
}

sub can_sync {
  my ($self, $ext_bug) = @_;
  return 1;
}

1;

__END__

=head1 NAME

Bugzilla::Extension::ExternalBugs::Type::Bugzilla

=head1 DESCRIPTION

Type represents a Bugzilla bug. It is an implementation of
L<Bugzilla::Extension::ExternalBugs::Type>, and thus provides all methods that
L<Bugzilla::Extension::ExternalBugs::Type> provides.

This type can sync data from remote Bugzilla sites to the local site.

=cut
