package Bugzilla::Extension::Voting::WebService;

use 5.10.1;
use strict;
use warnings;
use base qw(Bugzilla::WebService);
use Bugzilla::Bug;
use Bugzilla::User;
use Bugzilla::Constants;
use Bugzilla::Error;
use Bugzilla::Util qw(trim diff_arrays);
use Bugzilla::WebService::Util qw(validate);


use JSON qw(to_json from_json);

use constant PUBLIC_METHODS => qw(
  for_bugs
);

sub for_bugs {
  my ($self, $params) = @_;

  my $user = Bugzilla->login(LOGIN_REQUIRED);

  my $bug_ids = delete $params->{bug_ids};
  defined $bug_ids || ThrowCodeError('param_required', {param => 'bug_ids'});

  $user->visible_bugs($bug_ids);
  my @bugs = map { Bugzilla::Bug->check($_) } @$bug_ids;

  my $dbh = Bugzilla->dbh;

  my $sth_insertVotes = $dbh->prepare(
    'INSERT INTO votes (who, bug_id, vote_count)
                                         VALUES (?, ?, ?)'
  );

  my $reply = "";

  $dbh->bz_start_transaction();
  foreach my $bug (@bugs) {
    $bug->check_is_visible;

    unless ($bug->product_obj->{maxvotesperbug}
      && $bug->product_obj->{votesperuser})
    {
      $reply .= "Bug " . $bug->id . " cannot be voted for\n";
      next;
    }
    if ($bug->my_votes()) {
      $reply .= "Bug " . $bug->id . " has already been voted for\n";
      next;
    }
    $sth_insertVotes->execute($user->id, $bug->id, 1);
    $dbh->do(q{UPDATE bugs SET votes = "votes" + 1 WHERE bug_id = ?},
      undef, $bug->id);
    $reply .= "Voted for bug " . $bug->id . "\n";
  }
  $dbh->bz_commit_transaction();

  return $reply;
}

1;

__END__

=head1 NAME

Bugzilla::Extension::Voting::WebService - The Voting API

=head1 DESCRIPTION

This API allows you to vote for bugs.

=head1 METHODS

=head2 for_bugs

=over

=item B<Description>

Set Votes to 1 for a set of bugs if the bug has not been voted for.

=item B<Params>

B<array> of B<ints> bug_ids the list of bug IDs to ote for.

=item B<Returns>

Returns an OK message..

=back
