# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

package Bugzilla::Extension::Workflows::Util;

use 5.10.1;
use strict;
use warnings;

use parent qw(Exporter);
our @EXPORT = qw(
    get_manager
);

use Bugzilla::Error;

# This file can be loaded by your extension via
# "use Bugzilla::Extension::Workflows::Util". You can put functions
# used by your extension in here. (Make sure you also list them in
# @EXPORT.)


sub get_manager {
  my ($user) = @_;

  my $host     = Bugzilla->params->{LDAPMXserver};
  my $basedn   = Bugzilla->params->{LDAPMXBaseDN};
  my $pass     = Bugzilla->localconfig->{LDAPMXpass};
  my $searchdn = Bugzilla->params->{LDAPMXSearchDN};
  my $attr     = Bugzilla->params->{LDAPMXmailattribute};

  my $ldap = new Net::LDAP($host, scheme => 'ldaps', onerror => 'die');
  $ldap->bind(dn => $basedn, password => $pass);

  my $login = $user->login;

  # handle jfearn+test@redhat.com
  if ($login =~ m/([^@+]+)\+([^@]+)@([^@]+)$/) {
    $login = "$1\@$3";
  }

  my $search
    = $ldap->search(base => $searchdn, filter => 'rhatEmailAddress=' . $login);

  $search->code && die $search->error;

  my @addrs = qw/rhatPreferredAlias rhatPrimaryMail mail/;
  my ($manager, $uid, $man_uid, $man);

  # Throw a tantrum if there isn't an MX record
  unless ($search->entries) {
    ThrowUserError('cannot_update_invalid_redhat_mail', {account => $user->login});
  }

OUTER: foreach my $entry ($search->entries) {

    $uid = $entry->get_value('sendmailMTAAliasValue');
    $uid =~ s/\@.*$//;

    my $usearch
      = $ldap->search(base => 'ou=users,dc=redhat,dc=com', filter => "uid=$uid");
    $usearch->code && die $usearch->error;

    # If we have a match then it's a real user
    if ($usearch->entries) {
      foreach my $entry ($usearch->entries) {
        my $val = $entry->get_value('manager');

        if ($val && $val =~ /uid=([^,]+),/) {
          $man_uid = $1;
          if ($man_uid && $man_uid ne '') {

            my $msearch = $ldap->search(base => 'ou=users,dc=redhat,dc=com',
              filter => "uid=$man_uid");
            $msearch->code && die $msearch->error;
            foreach my $entry ($msearch->entries) {

              my $uuid = $entry->get_value('rhatUUID');
              if ($uuid && $uuid ne '') {
                $man = Bugzilla::User->new({extern_id => $uuid});
                if ($man && $man->is_enabled()) {
                  $manager = $man;
                  last OUTER;
                }
              }

              foreach my $addr (@addrs) {
                my $mail = $entry->get_value($addr);
                if ($mail) {
                  $man = Bugzilla::User->new({name => $mail});
                  if ($man && $man->is_enabled()) {
                    $manager = $man;
                    last OUTER;
                  }
                }
              }
            }
          }
        }
      }

      ThrowUserError("approvals_manager_disabled", {man_login => $man->login})
        if ($man && !$man->is_enabled());

      ThrowUserError("approvals_manager_not_found",
        {uid => $uid, login => $login, man_uid => $man_uid})
        unless ($manager);
    }
  }

  return ($manager);
}

1;
